@@ -337,7 +337,11 @@ def do_the_request(num):
                             config_set = True
                             set_config_key("info", "printer_id", str(the_json["printer_id"]))
 
-                        the_printer_name = the_json["printer_name"].encode("utf-8").strip()
+                        if IS_PY3:
+                            the_printer_name = str(the_json["printer_name"]).strip()
+                        else:
+                            the_printer_name = the_json["printer_name"].encode("utf-8").strip()
+
                         old_name = config.get("info", "printer_name")
                         if old_name != the_printer_name:
                             config_set = True
@@ -613,9 +617,11 @@ def do_the_request(num):
                                 if "restart" in action and action["restart"]:
                                     do_restart_octoprint = True
 
-                        # End loop
+                        # End plugin action loop
                         if do_restart_octoprint:
                             os.system("sudo service octoprint restart")
+
+                        website_ping_update("&plugin_actions_executed")
                     else:
                         # No plugins to install or settings to set
                         process_pending_settings()
@@ -648,7 +654,7 @@ def do_the_request(num):
 
                             default_cancel_gcode = ";disable motorsM84;disable all heaters{% snippet 'disable_hotends' %}{% snippet 'disable_bed' %};disable fanM106 S0"
 
-                            if "script" in octoprint_settings and "gcode" in octoprint_settings["scripts"]:
+                            if "scripts" in octoprint_settings and "gcode" in octoprint_settings["scripts"]:
                                 if "afterPrintCancelled" in octoprint_settings["scripts"]["gcode"]:
                                     current_cancel_gcode = octoprint_settings["scripts"]["gcode"]["afterPrintCancelled"]
 
@@ -664,6 +670,7 @@ def do_the_request(num):
 
                             if current_cancel_gcode or current_resume_gcode or current_pause_gcode:
                                 # One or all of the GCODE scripts we want to overwrite have values - sync with server!
+                                log("Synced local GCODE scripts to SP")
                                 website_ping_update("&gcode_scripts_backed_up=" + url_quote(json.dumps({
                                     "cancel_gcode": current_cancel_gcode,
                                     "pause_gcode": current_pause_gcode,
@@ -671,6 +678,7 @@ def do_the_request(num):
                                 })))
                             else:
                                 # No backups needed - user has not set anything
+                                log("No backups needed - no user modified GCODE scripts")
                                 website_ping_update("&no_gcode_script_backup_needed")
 
                             set_config_key("info", "gcode_scripts_backed_up", "True")
